==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QAbstractFileEngine_shell.h <==
#ifndef QABSTRACTFILEENGINE_SHELL_H
#define QABSTRACTFILEENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/private/qabstractfileengine_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qfiledevice.h>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QAbstractFileEngine_shell : public QAbstractFileEngine, public QtJambiShellInterface
{
public:
    QAbstractFileEngine_shell();
    ~QAbstractFileEngine_shell() override;

    QAbstractFileEngineIterator* beginEntryList(QDir::Filters filters0, const QStringList& filterNames1) override;
    bool caseSensitive() const override;
    bool cloneTo(QAbstractFileEngine* target0) override;
    bool close() override;
    bool copy(const QString& newName0) override;
    QAbstractFileEngineIterator* endEntryList() override;
    QStringList entryList(QDir::Filters filters0, const QStringList& filterNames1) const override;
    QAbstractFileEngine::FileFlags fileFlags(QAbstractFileEngine::FileFlags type0) const override;
    QString fileName(QAbstractFileEngine::FileName file0) const override;
    QDateTime fileTime(QAbstractFileEngine::FileTime time0) const override;
    bool flush() override;
    int handle() const override;
    QByteArray id() const override;
    bool isRelativePath() const override;
    bool isSequential() const override;
    bool link(const QString& newName0) override;
    bool mkdir(const QString& dirName0, bool createParentDirectories1, std::optional<QFileDevice::Permissions> permissions2) const override;
    bool open(QIODeviceBase::OpenMode openMode0, std::optional<QFileDevice::Permissions> permissions1) override;
    QString owner(QAbstractFileEngine::FileOwner arg__1) const override;
    uint ownerId(QAbstractFileEngine::FileOwner arg__1) const override;
    qint64 pos() const override;
    qint64 read(char* data0, qint64 maxlen1) override;
    qint64 readLine(char* data0, qint64 maxlen1) override;
    bool remove() override;
    bool rename(const QString& newName0) override;
    bool renameOverwrite(const QString& newName0) override;
    bool rmdir(const QString& dirName0, bool recurseParentDirectories1) const override;
    bool seek(qint64 pos0) override;
    void setFileName(const QString& file0) override;
    bool setFileTime(const QDateTime& newDate0, QAbstractFileEngine::FileTime time1) override;
    bool setPermissions(uint perms0) override;
    bool setSize(qint64 size0) override;
    qint64 size() const override;
    bool syncToDisk() override;
    qint64 write(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFileEngine_access : public QAbstractFileEngine
{
    void __qt_setError_QFileDevice_FileError_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint error0, jstring str1);
    jobject __qt_beginEntryList_QDir_Filters_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint filters0, jobject filterNames1);
    jboolean __qt_caseSensitive(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_cloneTo_QAbstractFileEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID target0);
    jboolean __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_copy_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jobject __qt_endEntryList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_entryList_QDir_Filters_cref_QStringList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint filters0, jobject filterNames1) const;
    jint __qt_fileFlags_QAbstractFileEngine_FileFlags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    jstring __qt_fileName_QAbstractFileEngine_FileName_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint file0) const;
    jobject __qt_fileTime_QAbstractFileEngine_FileTime_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint time0) const;
    jboolean __qt_flush(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_handle(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_id(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isRelativePath(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isSequential(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_link_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jboolean __qt_mkdir_cref_QString_bool_std_optional_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring dirName0, jboolean createParentDirectories1, jobject permissions2) const;
    jboolean __qt_open_QIODeviceBase_OpenMode_std_optional(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint openMode0, jobject permissions1);
    jstring __qt_owner_QAbstractFileEngine_FileOwner_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jint __qt_ownerId_QAbstractFileEngine_FileOwner_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jlong __qt_pos(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_read_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_readLine_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jboolean __qt_remove(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_rename_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jboolean __qt_renameOverwrite_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jboolean __qt_rmdir_cref_QString_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring dirName0, jboolean recurseParentDirectories1) const;
    jboolean __qt_seek_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong pos0);
    void __qt_setFileName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring file0);
    jboolean __qt_setFileTime_cref_QDateTime_QAbstractFileEngine_FileTime(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newDate0, jint time1);
    jboolean __qt_setPermissions_uint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint perms0);
    jboolean __qt_setSize_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong size0);
    jlong __qt_size(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_syncToDisk(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_write_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QABSTRACTFILEENGINE_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QAbstractFileEngine_shell.h <==
#ifndef QABSTRACTFILEENGINE_SHELL_H
#define QABSTRACTFILEENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/private/qabstractfileengine_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qfiledevice.h>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QAbstractFileEngine_shell : public QAbstractFileEngine, public QtJambiShellInterface
{
public:
    QAbstractFileEngine_shell();
    ~QAbstractFileEngine_shell() override;

    QAbstractFileEngineIterator* beginEntryList(QDir::Filters filters0, const QStringList& filterNames1) override;
    bool caseSensitive() const override;
    bool cloneTo(QAbstractFileEngine* target0) override;
    bool close() override;
    bool copy(const QString& newName0) override;
    QAbstractFileEngineIterator* endEntryList() override;
    QStringList entryList(QDir::Filters filters0, const QStringList& filterNames1) const override;
    QAbstractFileEngine::FileFlags fileFlags(QAbstractFileEngine::FileFlags type0) const override;
    QString fileName(QAbstractFileEngine::FileName file0) const override;
    QDateTime fileTime(QAbstractFileEngine::FileTime time0) const override;
    bool flush() override;
    int handle() const override;
    QByteArray id() const override;
    bool isRelativePath() const override;
    bool isSequential() const override;
    bool link(const QString& newName0) override;
    bool mkdir(const QString& dirName0, bool createParentDirectories1, std::optional<QFileDevice::Permissions> permissions2) const override;
    bool open(QIODeviceBase::OpenMode openMode0, std::optional<QFileDevice::Permissions> permissions1) override;
    QString owner(QAbstractFileEngine::FileOwner arg__1) const override;
    uint ownerId(QAbstractFileEngine::FileOwner arg__1) const override;
    qint64 pos() const override;
    qint64 read(char* data0, qint64 maxlen1) override;
    qint64 readLine(char* data0, qint64 maxlen1) override;
    bool remove() override;
    bool rename(const QString& newName0) override;
    bool renameOverwrite(const QString& newName0) override;
    bool rmdir(const QString& dirName0, bool recurseParentDirectories1) const override;
    bool seek(qint64 pos0) override;
    void setFileName(const QString& file0) override;
    bool setFileTime(const QDateTime& newDate0, QAbstractFileEngine::FileTime time1) override;
    bool setPermissions(uint perms0) override;
    bool setSize(qint64 size0) override;
    qint64 size() const override;
    bool syncToDisk() override;
    qint64 write(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractFileEngine_access : public QAbstractFileEngine
{
    void __qt_setError_QFileDevice_FileError_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint error0, jstring str1);
    jobject __qt_beginEntryList_QDir_Filters_cref_QStringList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint filters0, jobject filterNames1);
    jboolean __qt_caseSensitive_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_cloneTo_QAbstractFileEngine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID target0);
    jboolean __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_copy_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jobject __qt_endEntryList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_entryList_QDir_Filters_cref_QStringList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint filters0, jobject filterNames1) const;
    jint __qt_fileFlags_QAbstractFileEngine_FileFlags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    jstring __qt_fileName_QAbstractFileEngine_FileName_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint file0) const;
    jobject __qt_fileTime_QAbstractFileEngine_FileTime_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint time0) const;
    jboolean __qt_flush(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_handle_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_id_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isRelativePath_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isSequential_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_link_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jboolean __qt_mkdir_cref_QString_bool_std_optional_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring dirName0, jboolean createParentDirectories1, jobject permissions2) const;
    jboolean __qt_open_QIODeviceBase_OpenMode_std_optional(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint openMode0, jobject permissions1);
    jstring __qt_owner_QAbstractFileEngine_FileOwner_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jint __qt_ownerId_QAbstractFileEngine_FileOwner_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jlong __qt_pos_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_read_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_readLine_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jboolean __qt_remove(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_rename_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jboolean __qt_renameOverwrite_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring newName0);
    jboolean __qt_rmdir_cref_QString_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring dirName0, jboolean recurseParentDirectories1) const;
    jboolean __qt_seek_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong pos0);
    void __qt_setFileName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring file0);
    jboolean __qt_setFileTime_cref_QDateTime_QAbstractFileEngine_FileTime(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newDate0, jint time1);
    jboolean __qt_setPermissions_uint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint perms0);
    jboolean __qt_setSize_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong size0);
    jlong __qt_size_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_syncToDisk(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_write_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QABSTRACTFILEENGINE_SHELL_H
